@@ -1,6 +1,4 @@
 import logging
-import platform
-import warnings
 
 # pylint: disable=wrong-import-position
 from robotlibcore import DynamicCore
@@ -13,6 +11,12 @@ from RPA.Windows.keywords import (
     WindowKeywords,
 )
 
+from RPA.Windows import utils
+
+if utils.is_windows():
+    import uiautomation as auto
+    from uiautomation.uiautomation import Logger
+
 
 class Windows(DynamicCore):
     """The `Windows` is a library that can be used for Windows desktop automation.
@@ -25,16 +29,13 @@ class Windows(DynamicCore):
 
     **About terminology**
 
-    ***ControlType***
-
-    Value referred to by locator keys `type:` or `control`. Represents type of application
+    **ControlType** is a value referred to by locator keys `type:` or `control`. Represents type of application
     object, which can be e.g. `Window`, `Button` or `ListItem`.
 
-    ***Element***
-
-    Entity of an application structure (e.g. certain button in a window), which can be
+    **Element** is an entity of an application structure (e.g. certain button in a window), which can be
     identified by a locator.
 
+
     **Locators**
 
     Locators are based on different strategies that can used identify Control object.
@@ -56,16 +57,34 @@ class Windows(DynamicCore):
     offset          offset coordinates (x (int), y (int)) from control center
     executable      target window by its executable name
     handle          target window handle (int)
-    desktop         target desktop
+    desktop         *SPECIAL* target desktop, no value for the key e.g. `desktop and name:Calculator`
     process         *NOT YET SUPPORTED* target window by its executable's process id
     depth           searchDepth (int) for finding Control (default 8)
     =============== =======================
 
-    Getting control over application object (Control) is done usually by first executing
-    keyword ``Control Window`` which by default will search from desktop ControlType
-    WindowControl objects with the given locator.
+    **About root element on locators**
 
-    Keyword ``Control Window`` can also be used to target application child WindowControl objects.
+    Locators work on currently active `root element`. At the start `root element` is the whole
+    desktop. There are different ways on changing this root element.
+
+    Keyword ``Control Window`` is the most common method of setting certain system window
+    as a root element for further actions using locators.
+
+    Locators themselves support cascading syntax (denoted by character `>` in the locator string),
+    which can denote root element in "parent (root) & child" terms.
+
+    For example.
+
+    .. code-block:: robotframework
+
+        Click  id:controls > id:activate
+
+    On the above example the left side of the `>` character, `id:controls`, represents the root element
+    (can be called as "parent element" in this case). Right side of the locator string, `id:activate`,
+    represents "child" element and it will be searched under the "parent element".
+
+    This way element search is more efficient, because search are restricted to certain section of element
+    tree which can be quite huge especially on the desktop level and in certain applications.
 
     Keyword examples:
 
@@ -75,7 +94,7 @@ class Windows(DynamicCore):
         Control Window    Calculator  # will execute search by 'name:Calculator'
         Control Window    executable:Spotify.exe
 
-    some example locators:
+    some example locators, `and` can be omitted ie. space ` ` between locator keys means the same thing as `and`:
 
     .. code-block:: bash
 
@@ -85,10 +104,26 @@ class Windows(DynamicCore):
         id:Units1 > name:${unit}
         class:Button offset:370,0
 
+    **About locator restrictions**
+
+    Visual locators are not supported in this library and they can't be used in the same chain with these
+    Windows locators. Visual locators are supported by the `RPA.Desktop` library. Locator chaining (image and
+    Windows locators) support will be added in the future.
+
+    Locator syntax does not yet support OR operation (only AND operations).
+
+    **About search depth**
+
+    The library does element search depth by default to the level of 8. This means that locator will look into
+    8 levels of elements under element tree of the root element. This can lead into situation where element
+    can't be found. To fix this it is recommended to set root element which can be found within 8 levels OR
+    defining `depth` in the locator string to a bigger value, e.g. `id:deeplyNestedButton depth:16`. Useful
+    keywords for setting root element are ``Control Window``, ``Set Anchor`` and ``Get Element``.
+
 
     **Keyboard and mouse**
 
-    Keyword
+    TBD
 
     **How to inspect**
 
@@ -128,7 +163,7 @@ class Windows(DynamicCore):
             Click    id:clearButton
             Send Keys   96+4=
             ${result}=    Access Attribute or Method    id:CalculatorResults    Name
-            Log To Console    n${result}
+            Log To Console    ${result}
 
 
     """  # noqa: E501
@@ -143,7 +178,11 @@ class Windows(DynamicCore):
         self.simulate_move = False
         self.window = None
         self.anchor_element = None
+        # prevent comtypes writing lot of log messages
+        comtypelogger = logging.getLogger("comtypes")
+        comtypelogger.propagate = False
 
+        Logger.SetLogFile("")
         # Register keyword libraries to LibCore
         libraries = [
             ActionKeywords(self),
