@@ -19,7 +19,7 @@ class WindowKeywords(LibraryContext):
 
     @keyword(tags=["window"])
     def control_window(self, locator: str = None) -> int:
-        """Control window defined by the locator string.
+        """Controls the window defined by the locator.
 
         This means that this window is used as a root element
         for all the following keywords using locators.
@@ -56,13 +56,13 @@ class WindowKeywords(LibraryContext):
         self.ctx.window.SetActive()
         handle = self.ctx.window.NativeWindowHandle
         self.ctx.window.MoveCursorToMyCenter(simulateMove=self.ctx.simulate_move)
-        time.sleep(1.0)
+        # time.sleep(1.0)
         return handle
 
     @keyword(tags=["window"])
     def minimize_window(self, locator: str = None) -> None:
         """Minimize the current active window or the window defined
-        by the locator string.
+        by the locator.
 
         :param locator: string locator
 
@@ -87,7 +87,7 @@ class WindowKeywords(LibraryContext):
     @keyword(tags=["window"])
     def maximize_window(self, locator: str = None) -> None:
         """Minimize the current active window or the window defined
-        by the locator string.
+        by the locator.
 
         :param locator: string locator
 
@@ -177,7 +177,7 @@ class WindowKeywords(LibraryContext):
 
     @keyword(tags=["window"])
     def close_current_window(self) -> bool:
-        """Closes current active window or log warning message
+        """Closes current active window or logs a warning message.
 
         Example:
 
@@ -185,11 +185,13 @@ class WindowKeywords(LibraryContext):
 
             Close Current Window
         """
-        # TODO. Fix this keyword
         if not self.ctx.window:
             self.ctx.logger.warning("There is no active window")
             return False
         pid = self.ctx.window.ProcessId
-        self.ctx.logger.info("Closing window with PID: %s" % pid)
+        name = self.ctx.window.Name
+        self.ctx.logger.info(
+            'Closing window with Name:"%s", ProcessId: %s' % (name, pid)
+        )
         os.kill(pid, signal.SIGTERM)
         return True
